﻿Imports System.Collections.ObjectModel
Imports System.ComponentModel
Public Class NotesViewModel
    Inherits BaseViewModel

    Private _service As INoticeDataService

    Public Sub New()
        NotesView = CollectionViewSource.GetDefaultView(Notes)
        NotesView.Filter = AddressOf NotesViewFilter
    End Sub

    Public Sub New(service As INoticeDataService)
        _service = service
        LoadNotes()
        NotesView = CollectionViewSource.GetDefaultView(Notes)
        NotesView.Filter = AddressOf NotesViewFilter
    End Sub

    Private _notes As ObservableCollection(Of NoteViewModel) = New ObservableCollection(Of NoteViewModel)
    Public Property Notes() As ObservableCollection(Of NoteViewModel)
        Get
            Return _notes
        End Get
        Set(ByVal value As ObservableCollection(Of NoteViewModel))
            ChangePropIfDifferent(value, _notes)
        End Set
    End Property

    Private _selectedNote As NoteViewModel
    Public Property SelectedNote() As NoteViewModel
        Get
            Return _selectedNote
        End Get
        Set(ByVal value As NoteViewModel)
            ChangePropIfDifferent(value, _selectedNote)
        End Set
    End Property

    Private _notesView As ICollectionView
    Public Property NotesView() As ICollectionView
        Get
            Return _notesView
        End Get
        Set(ByVal value As ICollectionView)
            ChangePropIfDifferent(value, _notesView)
        End Set
    End Property
    Private Function NotesViewFilter(obj As Object) As Boolean
        Dim currentNote As NoteViewModel = CType(obj, NoteViewModel)
        If NotesFilterString = String.Empty Then
            Return True
        End If
        Return currentNote.NoteName.ToLower.Contains(NotesFilterString.ToLower) OrElse currentNote.NoteText.ToLower.Contains(NotesFilterString.ToLower)
    End Function

    Private _notesFilterString As String = String.Empty
    Public Property NotesFilterString() As String
        Get
            Return _notesFilterString
        End Get
        Set(ByVal value As String)
            ChangePropIfDifferent(value, _notesFilterString)
            NotesView.Refresh()
        End Set
    End Property

    Public Sub LoadNotes()
        Notes = _service.GetNotes
        createDummyNotes()
    End Sub
    Public Sub SaveNotes()
        _service.Save(Notes)
    End Sub


    Public ReadOnly Property AddNoteCommand As New RelayCommand(AddressOf AddNoteCommand_Execute, Function(o) True)
    Private Sub AddNoteCommand_Execute(obj As Object)
        Notes.Add(DirectCast(obj, NoteViewModel))
    End Sub

    Sub createDummyNotes()
        If Not IO.File.Exists(Application.DataFile) Then
            For i As Integer = 1 To 20
                Notes.Add(New NoteViewModel($"Name {i}", $"Text {i}"))
            Next
        End If
    End Sub
End Class